# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ibeo_msgs/msg/error_warning.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ibeo_msgs.msg import ibeo_data_header_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_ibeo__data__header__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/ibeo_msgs/msg/error_warning.proto\x12*make87_messages_ros2.rolling.ibeo_msgs.msg\x1a\x41make87_messages_ros2/rolling/ibeo_msgs/msg/ibeo_data_header.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xbb\x0b\n\x0c\x45rrorWarning\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12O\n\x0bibeo_header\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.ibeo_msgs.msg.IbeoDataHeader\x12\x1a\n\x12\x65rr_internal_error\x18\x03 \x01(\x08\x12\x19\n\x11\x65rr_motor_1_fault\x18\x04 \x01(\x08\x12\'\n\x1f\x65rr_buffer_error_xmt_incomplete\x18\x05 \x01(\x08\x12!\n\x19\x65rr_buffer_error_overflow\x18\x06 \x01(\x08\x12 \n\x18\x65rr_apd_over_temperature\x18\x07 \x01(\x08\x12!\n\x19\x65rr_apd_under_temperature\x18\x08 \x01(\x08\x12)\n!err_apd_temperature_sensor_defect\x18\t \x01(\x08\x12\x19\n\x11\x65rr_motor_2_fault\x18\n \x01(\x08\x12\x19\n\x11\x65rr_motor_3_fault\x18\x0b \x01(\x08\x12\x19\n\x11\x65rr_motor_4_fault\x18\x0c \x01(\x08\x12\x19\n\x11\x65rr_motor_5_fault\x18\r \x01(\x08\x12\x1c\n\x14\x65rr_int_no_scan_data\x18\x0e \x01(\x08\x12#\n\x1b\x65rr_int_communication_error\x18\x0f \x01(\x08\x12#\n\x1b\x65rr_int_incorrect_scan_data\x18\x10 \x01(\x08\x12(\n err_config_fpga_not_configurable\x18\x11 \x01(\x08\x12(\n err_config_incorrect_config_data\x18\x12 \x01(\x08\x12,\n$err_config_contains_incorrect_params\x18\x13 \x01(\x08\x12#\n\x1b\x65rr_timeout_data_processing\x18\x14 \x01(\x08\x12/\n\'err_timeout_env_model_computation_reset\x18\x15 \x01(\x08\x12#\n\x1bwrn_int_communication_error\x18\x16 \x01(\x08\x12\x1b\n\x13wrn_low_temperature\x18\x17 \x01(\x08\x12\x1c\n\x14wrn_high_temperature\x18\x18 \x01(\x08\x12\x17\n\x0fwrn_int_motor_1\x18\x19 \x01(\x08\x12\x16\n\x0ewrn_sync_error\x18\x1a \x01(\x08\x12\'\n\x1fwrn_laser_1_start_pulse_missing\x18\x1b \x01(\x08\x12\'\n\x1fwrn_laser_2_start_pulse_missing\x18\x1c \x01(\x08\x12!\n\x19wrn_can_interface_blocked\x18\x1d \x01(\x08\x12!\n\x19wrn_eth_interface_blocked\x18\x1e \x01(\x08\x12#\n\x1bwrn_incorrect_can_data_rcvd\x18\x1f \x01(\x08\x12#\n\x1bwrn_int_incorrect_scan_data\x18  \x01(\x08\x12%\n\x1dwrn_eth_unkwn_incomplete_data\x18! \x01(\x08\x12+\n#wrn_incorrect_or_forbidden_cmd_rcvd\x18\" \x01(\x08\x12!\n\x19wrn_memory_access_failure\x18# \x01(\x08\x12\x18\n\x10wrn_int_overflow\x18$ \x01(\x08\x12#\n\x1bwrn_ego_motion_data_missing\x18% \x01(\x08\x12%\n\x1dwrn_incorrect_mounting_params\x18& \x01(\x08\x12(\n wrn_no_obj_comp_due_to_scan_freq\x18\' \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ibeo_msgs.msg.error_warning_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ERRORWARNING']._serialized_start=234
  _globals['_ERRORWARNING']._serialized_end=1701
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.fadecandy_msgs.msg import led_strip_pb2 as _led_strip_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LEDArray(_message.Message):
    __slots__ = ["header", "strips"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STRIPS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    strips: _containers.RepeatedCompositeFieldContainer[_led_strip_pb2.LEDStrip]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., strips: _Optional[_Iterable[_Union[_led_strip_pb2.LEDStrip, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.controller_manager_msgs.msg import hardware_component_state_pb2 as _hardware_component_state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListHardwareComponentsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListHardwareComponentsResponse(_message.Message):
    __slots__ = ["component"]
    COMPONENT_FIELD_NUMBER: _ClassVar[int]
    component: _containers.RepeatedCompositeFieldContainer[_hardware_component_state_pb2.HardwareComponentState]
    def __init__(self, component: _Optional[_Iterable[_Union[_hardware_component_state_pb2.HardwareComponentState, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg import roi_observation_result_data_pb2 as _roi_observation_result_data_pb2
from make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg import roi_observation_safety_data_pb2 as _roi_observation_safety_data_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ROI(_message.Message):
    __slots__ = ["id", "result_data", "safety_data", "distance_value"]
    ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_DATA_FIELD_NUMBER: _ClassVar[int]
    SAFETY_DATA_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_VALUE_FIELD_NUMBER: _ClassVar[int]
    id: int
    result_data: _roi_observation_result_data_pb2.ROIObservationResultData
    safety_data: _roi_observation_safety_data_pb2.ROIObservationSafetyData
    distance_value: int
    def __init__(self, id: _Optional[int] = ..., result_data: _Optional[_Union[_roi_observation_result_data_pb2.ROIObservationResultData, _Mapping]] = ..., safety_data: _Optional[_Union[_roi_observation_safety_data_pb2.ROIObservationSafetyData, _Mapping]] = ..., distance_value: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.humble.sbg_driver.msg import sbg_gps_pos_status_pb2 as _sbg_gps_pos_status_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SbgGpsPos(_message.Message):
    __slots__ = ["header", "ros2_header", "time_stamp", "status", "gps_tow", "latitude", "longitude", "altitude", "undulation", "position_accuracy", "num_sv_tracked", "num_sv_used", "base_station_id", "diff_age"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    TIME_STAMP_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    GPS_TOW_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_FIELD_NUMBER: _ClassVar[int]
    UNDULATION_FIELD_NUMBER: _ClassVar[int]
    POSITION_ACCURACY_FIELD_NUMBER: _ClassVar[int]
    NUM_SV_TRACKED_FIELD_NUMBER: _ClassVar[int]
    NUM_SV_USED_FIELD_NUMBER: _ClassVar[int]
    BASE_STATION_ID_FIELD_NUMBER: _ClassVar[int]
    DIFF_AGE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    time_stamp: int
    status: _sbg_gps_pos_status_pb2.SbgGpsPosStatus
    gps_tow: int
    latitude: float
    longitude: float
    altitude: float
    undulation: float
    position_accuracy: _vector3_pb2.Vector3
    num_sv_tracked: int
    num_sv_used: int
    base_station_id: int
    diff_age: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., time_stamp: _Optional[int] = ..., status: _Optional[_Union[_sbg_gps_pos_status_pb2.SbgGpsPosStatus, _Mapping]] = ..., gps_tow: _Optional[int] = ..., latitude: _Optional[float] = ..., longitude: _Optional[float] = ..., altitude: _Optional[float] = ..., undulation: _Optional[float] = ..., position_accuracy: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., num_sv_tracked: _Optional[int] = ..., num_sv_used: _Optional[int] = ..., base_station_id: _Optional[int] = ..., diff_age: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ublox_msgs/msg/mon_hw6.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/humble/ublox_msgs/msg/mon_hw6.proto\x12*make87_messages_ros2.humble.ublox_msgs.msg\x1a!make87_messages/core/header.proto\"\xdb\x02\n\x06MonHW6\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07pin_sel\x18\x02 \x01(\r\x12\x10\n\x08pin_bank\x18\x03 \x01(\r\x12\x0f\n\x07pin_dir\x18\x04 \x01(\r\x12\x0f\n\x07pin_val\x18\x05 \x01(\r\x12\x14\n\x0cnoise_per_ms\x18\x06 \x01(\r\x12\x0f\n\x07\x61gc_cnt\x18\x07 \x01(\r\x12\x10\n\x08\x61_status\x18\x08 \x01(\r\x12\x0f\n\x07\x61_power\x18\t \x01(\r\x12\r\n\x05\x66lags\x18\n \x01(\r\x12\x11\n\treserved0\x18\x0b \x01(\r\x12\x11\n\tused_mask\x18\x0c \x01(\r\x12\n\n\x02vp\x18\r \x03(\r\x12\x0f\n\x07jam_ind\x18\x0e \x01(\r\x12\x11\n\treserved1\x18\x0f \x03(\r\x12\x0f\n\x07pin_irq\x18\x10 \x01(\r\x12\x0e\n\x06pull_h\x18\x11 \x01(\r\x12\x0e\n\x06pull_l\x18\x12 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ublox_msgs.msg.mon_hw6_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MONHW6']._serialized_start=140
  _globals['_MONHW6']._serialized_end=487
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg import station_pb2 as _station_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Order(_message.Message):
    __slots__ = ["header", "order_id", "order_name", "stations"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    ORDER_NAME_FIELD_NUMBER: _ClassVar[int]
    STATIONS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    order_id: int
    order_name: str
    stations: _containers.RepeatedCompositeFieldContainer[_station_pb2.Station]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., order_id: _Optional[int] = ..., order_name: _Optional[str] = ..., stations: _Optional[_Iterable[_Union[_station_pb2.Station, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ds_dbw_msgs/msg/brake_report.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ds_dbw_msgs.msg import cmd_src_pb2 as make87__messages__ros2_dot_humble_dot_ds__dbw__msgs_dot_msg_dot_cmd__src__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/humble/ds_dbw_msgs/msg/brake_report.proto\x12+make87_messages_ros2.humble.ds_dbw_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x39make87_messages_ros2/humble/ds_dbw_msgs/msg/cmd_src.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xb7\x07\n\x0b\x42rakeReport\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x10\n\x08\x63md_type\x18\x03 \x01(\r\x12\x16\n\x0epressure_input\x18\x04 \x01(\x02\x12\x14\n\x0cpressure_cmd\x18\x05 \x01(\x02\x12\x17\n\x0fpressure_output\x18\x06 \x01(\x02\x12\x14\n\x0ctorque_input\x18\x07 \x01(\x02\x12\x12\n\ntorque_cmd\x18\x08 \x01(\x02\x12\x15\n\rtorque_output\x18\t \x01(\x02\x12\x11\n\taccel_cmd\x18\n \x01(\x02\x12\x14\n\x0c\x61\x63\x63\x65l_output\x18\x0b \x01(\x02\x12\x15\n\rpercent_input\x18\x0c \x01(\x02\x12\x13\n\x0bpercent_cmd\x18\r \x01(\x02\x12\x16\n\x0epercent_output\x18\x0e \x01(\x02\x12\x10\n\x08\x62tsi_cmd\x18\x0f \x01(\x08\x12\x15\n\ryield_request\x18\x10 \x01(\x08\x12\x16\n\x0elimiting_value\x18\x11 \x01(\x08\x12\x15\n\rlimiting_rate\x18\x12 \x01(\x08\x12\x18\n\x10\x65xternal_control\x18\x13 \x01(\x08\x12\r\n\x05ready\x18\x14 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x15 \x01(\x08\x12\x17\n\x0foverride_active\x18\x16 \x01(\x08\x12\x16\n\x0eoverride_other\x18\x17 \x01(\x08\x12\x18\n\x10override_latched\x18\x18 \x01(\x08\x12\x0f\n\x07timeout\x18\x19 \x01(\x08\x12\r\n\x05\x66\x61ult\x18\x1a \x01(\x08\x12\x0f\n\x07\x62\x61\x64_crc\x18\x1b \x01(\x08\x12\x0e\n\x06\x62\x61\x64_rc\x18\x1c \x01(\x08\x12\x10\n\x08\x64\x65graded\x18\x1d \x01(\x08\x12\x13\n\x0blimit_value\x18\x1e \x01(\x02\x12 \n\x18\x62rake_available_duration\x18\x1f \x01(\x02\x12\x1c\n\x14\x62rake_available_full\x18  \x01(\x08\x12\x16\n\x0ereq_shift_park\x18! \x01(\x08\x12\x16\n\x0ereq_park_brake\x18\" \x01(\x08\x12\x17\n\x0f\x65xternal_button\x18# \x01(\x08\x12\x18\n\x10\x63omms_loss_armed\x18$ \x01(\x08\x12\x44\n\x07\x63md_src\x18% \x01(\x0b\x32\x33.make87_messages_ros2.humble.ds_dbw_msgs.msg.CmdSrcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ds_dbw_msgs.msg.brake_report_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BRAKEREPORT']._serialized_start=261
  _globals['_BRAKEREPORT']._serialized_end=1212
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/irobot_create_msgs/msg/wheel_ticks.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/irobot_create_msgs/msg/wheel_ticks.proto\x12\x33make87_messages_ros2.rolling.irobot_create_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"x\n\nWheelTicks\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x12\n\nticks_left\x18\x02 \x01(\x05\x12\x13\n\x0bticks_right\x18\x03 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.irobot_create_msgs.msg.wheel_ticks_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_WHEELTICKS']._serialized_start=182
  _globals['_WHEELTICKS']._serialized_end=302
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/bosch_locator_bridge/msg/client_expand_map_visualization.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.bosch_locator_bridge.msg import client_expand_map_overwrite_zone_information_pb2 as make87__messages__ros2_dot_humble_dot_bosch__locator__bridge_dot_msg_dot_client__expand__map__overwrite__zone__information__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_array_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__array__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nZmake87_messages_ros2/humble/bosch_locator_bridge/msg/client_expand_map_visualization.proto\x12\x34make87_messages_ros2.humble.bosch_locator_bridge.msg\x1a!make87_messages/core/header.proto\x1agmake87_messages_ros2/humble/bosch_locator_bridge/msg/client_expand_map_overwrite_zone_information.proto\x1a=make87_messages_ros2/humble/builtin_interfaces/msg/time.proto\x1a>make87_messages_ros2/humble/geometry_msgs/msg/pose_array.proto\"\x92\x03\n\x1c\x43lientExpandMapVisualization\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12K\n\ttimestamp\x18\x02 \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12\x18\n\x10visualization_id\x18\x03 \x01(\x04\x12l\n\x05zones\x18\x04 \x03(\x0b\x32].make87_messages_ros2.humble.bosch_locator_bridge.msg.ClientExpandMapOverwriteZoneInformation\x12Q\n\x0fprior_map_poses\x18\x05 \x01(\x0b\x32\x38.make87_messages_ros2.humble.geometry_msgs.msg.PoseArray\x12\x1c\n\x14prior_map_pose_types\x18\x06 \x03(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.bosch_locator_bridge.msg.client_expand_map_visualization_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CLIENTEXPANDMAPVISUALIZATION']._serialized_start=416
  _globals['_CLIENTEXPANDMAPVISUALIZATION']._serialized_end=818
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rosapi_msgs/srv/get_action_servers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/rosapi_msgs/srv/get_action_servers.proto\x12*make87_messages_ros2.jazzy.rosapi_msgs.srv\"\x19\n\x17GetActionServersRequest\"2\n\x18GetActionServersResponse\x12\x16\n\x0e\x61\x63tion_servers\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rosapi_msgs.srv.get_action_servers_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETACTIONSERVERSREQUEST']._serialized_start=115
  _globals['_GETACTIONSERVERSREQUEST']._serialized_end=140
  _globals['_GETACTIONSERVERSRESPONSE']._serialized_start=142
  _globals['_GETACTIONSERVERSRESPONSE']._serialized_end=192
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class NavCOV(_message.Message):
    __slots__ = ["i_tow", "version", "pos_cov_valid", "vel_cov_valid", "reserved_0", "pos_cov_nn", "pos_cov_ne", "pos_cov_nd", "pos_cov_ee", "pos_cov_ed", "pos_cov_dd", "vel_cov_nn", "vel_cov_ne", "vel_cov_nd", "vel_cov_ee", "vel_cov_ed", "vel_cov_dd"]
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    POS_COV_VALID_FIELD_NUMBER: _ClassVar[int]
    VEL_COV_VALID_FIELD_NUMBER: _ClassVar[int]
    RESERVED_0_FIELD_NUMBER: _ClassVar[int]
    POS_COV_NN_FIELD_NUMBER: _ClassVar[int]
    POS_COV_NE_FIELD_NUMBER: _ClassVar[int]
    POS_COV_ND_FIELD_NUMBER: _ClassVar[int]
    POS_COV_EE_FIELD_NUMBER: _ClassVar[int]
    POS_COV_ED_FIELD_NUMBER: _ClassVar[int]
    POS_COV_DD_FIELD_NUMBER: _ClassVar[int]
    VEL_COV_NN_FIELD_NUMBER: _ClassVar[int]
    VEL_COV_NE_FIELD_NUMBER: _ClassVar[int]
    VEL_COV_ND_FIELD_NUMBER: _ClassVar[int]
    VEL_COV_EE_FIELD_NUMBER: _ClassVar[int]
    VEL_COV_ED_FIELD_NUMBER: _ClassVar[int]
    VEL_COV_DD_FIELD_NUMBER: _ClassVar[int]
    i_tow: int
    version: int
    pos_cov_valid: int
    vel_cov_valid: int
    reserved_0: _containers.RepeatedScalarFieldContainer[int]
    pos_cov_nn: float
    pos_cov_ne: float
    pos_cov_nd: float
    pos_cov_ee: float
    pos_cov_ed: float
    pos_cov_dd: float
    vel_cov_nn: float
    vel_cov_ne: float
    vel_cov_nd: float
    vel_cov_ee: float
    vel_cov_ed: float
    vel_cov_dd: float
    def __init__(self, i_tow: _Optional[int] = ..., version: _Optional[int] = ..., pos_cov_valid: _Optional[int] = ..., vel_cov_valid: _Optional[int] = ..., reserved_0: _Optional[_Iterable[int]] = ..., pos_cov_nn: _Optional[float] = ..., pos_cov_ne: _Optional[float] = ..., pos_cov_nd: _Optional[float] = ..., pos_cov_ee: _Optional[float] = ..., pos_cov_ed: _Optional[float] = ..., pos_cov_dd: _Optional[float] = ..., vel_cov_nn: _Optional[float] = ..., vel_cov_ne: _Optional[float] = ..., vel_cov_nd: _Optional[float] = ..., vel_cov_ee: _Optional[float] = ..., vel_cov_ed: _Optional[float] = ..., vel_cov_dd: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/slg_msgs/msg/segment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/rolling/slg_msgs/msg/segment.proto\x12)make87_messages_ros2.rolling.slg_msgs.msg\x1a:make87_messages_ros2/rolling/geometry_msgs/msg/point.proto\"\xb7\x02\n\x07Segment\x12\n\n\x02id\x18\x01 \x01(\x04\x12\r\n\x05label\x18\x02 \x01(\r\x12\x18\n\x10\x61ngular_distance\x18\x03 \x01(\x01\x12W\n\x18last_point_prior_segment\x18\x04 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Point\x12W\n\x18\x66irst_point_next_segment\x18\x05 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Point\x12\x45\n\x06points\x18\x06 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Pointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.slg_msgs.msg.segment_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SEGMENT']._serialized_start=163
  _globals['_SEGMENT']._serialized_end=474
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/output_paths.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/rolling/sick_safetyscanners2_interfaces/msg/output_paths.proto\x12@make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg\"`\n\x0bOutputPaths\x12\x0e\n\x06status\x18\x01 \x03(\x08\x12\x0f\n\x07is_safe\x18\x02 \x03(\x08\x12\x10\n\x08is_valid\x18\x03 \x03(\x08\x12\x1e\n\x16\x61\x63tive_monitoring_case\x18\x04 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sick_safetyscanners2_interfaces.msg.output_paths_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OUTPUTPATHS']._serialized_start=153
  _globals['_OUTPUTPATHS']._serialized_end=249
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GPSRTK(_message.Message):
    __slots__ = ["header", "rtk_receiver_id", "wn", "tow", "rtk_health", "rtk_rate", "nsats", "baseline_a", "baseline_b", "baseline_c", "accuracy", "iar_num_hypotheses"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RTK_RECEIVER_ID_FIELD_NUMBER: _ClassVar[int]
    WN_FIELD_NUMBER: _ClassVar[int]
    TOW_FIELD_NUMBER: _ClassVar[int]
    RTK_HEALTH_FIELD_NUMBER: _ClassVar[int]
    RTK_RATE_FIELD_NUMBER: _ClassVar[int]
    NSATS_FIELD_NUMBER: _ClassVar[int]
    BASELINE_A_FIELD_NUMBER: _ClassVar[int]
    BASELINE_B_FIELD_NUMBER: _ClassVar[int]
    BASELINE_C_FIELD_NUMBER: _ClassVar[int]
    ACCURACY_FIELD_NUMBER: _ClassVar[int]
    IAR_NUM_HYPOTHESES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    rtk_receiver_id: int
    wn: int
    tow: int
    rtk_health: int
    rtk_rate: int
    nsats: int
    baseline_a: int
    baseline_b: int
    baseline_c: int
    accuracy: int
    iar_num_hypotheses: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., rtk_receiver_id: _Optional[int] = ..., wn: _Optional[int] = ..., tow: _Optional[int] = ..., rtk_health: _Optional[int] = ..., rtk_rate: _Optional[int] = ..., nsats: _Optional[int] = ..., baseline_a: _Optional[int] = ..., baseline_b: _Optional[int] = ..., baseline_c: _Optional[int] = ..., accuracy: _Optional[int] = ..., iar_num_hypotheses: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MrrHeaderSensorPosition(_message.Message):
    __slots__ = ["header", "ros2_header", "can_sensor_polarity", "can_sensor_lat_offset", "can_sensor_long_offset", "can_sensor_hangle_offset"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_SENSOR_POLARITY_FIELD_NUMBER: _ClassVar[int]
    CAN_SENSOR_LAT_OFFSET_FIELD_NUMBER: _ClassVar[int]
    CAN_SENSOR_LONG_OFFSET_FIELD_NUMBER: _ClassVar[int]
    CAN_SENSOR_HANGLE_OFFSET_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    can_sensor_polarity: bool
    can_sensor_lat_offset: float
    can_sensor_long_offset: float
    can_sensor_hangle_offset: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., can_sensor_polarity: bool = ..., can_sensor_lat_offset: _Optional[float] = ..., can_sensor_long_offset: _Optional[float] = ..., can_sensor_hangle_offset: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from make87_messages_ros2.humble.ublox_ubx_msgs.msg import sig_data_pb2 as _sig_data_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXNavSig(_message.Message):
    __slots__ = ["header", "ros2_header", "itow", "version", "num_sigs", "reserved_0", "sig_data"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    ITOW_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NUM_SIGS_FIELD_NUMBER: _ClassVar[int]
    RESERVED_0_FIELD_NUMBER: _ClassVar[int]
    SIG_DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    itow: int
    version: int
    num_sigs: int
    reserved_0: _containers.RepeatedScalarFieldContainer[int]
    sig_data: _containers.RepeatedCompositeFieldContainer[_sig_data_pb2.SigData]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., itow: _Optional[int] = ..., version: _Optional[int] = ..., num_sigs: _Optional[int] = ..., reserved_0: _Optional[_Iterable[int]] = ..., sig_data: _Optional[_Iterable[_Union[_sig_data_pb2.SigData, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConfigureOutputsPwmFreqCmd(_message.Message):
    __slots__ = ["header", "confirm", "min_pwm_pct", "max_pwm_pct", "pwm_freq"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CONFIRM_FIELD_NUMBER: _ClassVar[int]
    MIN_PWM_PCT_FIELD_NUMBER: _ClassVar[int]
    MAX_PWM_PCT_FIELD_NUMBER: _ClassVar[int]
    PWM_FREQ_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    confirm: bool
    min_pwm_pct: int
    max_pwm_pct: int
    pwm_freq: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., confirm: bool = ..., min_pwm_pct: _Optional[int] = ..., max_pwm_pct: _Optional[int] = ..., pwm_freq: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ibeo_msgs/msg/scan_data2205.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import ibeo_data_header_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_ibeo__data__header__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import scan_point2205_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_scan__point2205__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import scanner_info2205_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_scanner__info2205__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/ibeo_msgs/msg/scan_data2205.proto\x12*make87_messages_ros2.rolling.ibeo_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x41make87_messages_ros2/rolling/ibeo_msgs/msg/ibeo_data_header.proto\x1a?make87_messages_ros2/rolling/ibeo_msgs/msg/scan_point2205.proto\x1a\x41make87_messages_ros2/rolling/ibeo_msgs/msg/scanner_info2205.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xcf\x04\n\x0cScanData2205\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12O\n\x0bibeo_header\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.ibeo_msgs.msg.IbeoDataHeader\x12R\n\x0fscan_start_time\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x1c\n\x14scan_end_time_offset\x18\x04 \x01(\r\x12\x12\n\nfused_scan\x18\x05 \x01(\x08\x12\x13\n\x0bmirror_side\x18\x06 \x01(\r\x12\x19\n\x11\x63oordinate_system\x18\x07 \x01(\r\x12\x13\n\x0bscan_number\x18\x08 \x01(\r\x12\x13\n\x0bscan_points\x18\t \x01(\r\x12\x1f\n\x17number_of_scanner_infos\x18\n \x01(\r\x12V\n\x11scanner_info_list\x18\x0b \x03(\x0b\x32;.make87_messages_ros2.rolling.ibeo_msgs.msg.ScannerInfo2205\x12R\n\x0fscan_point_list\x18\x0c \x03(\x0b\x32\x39.make87_messages_ros2.rolling.ibeo_msgs.msg.ScanPoint2205b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ibeo_msgs.msg.scan_data2205_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCANDATA2205']._serialized_start=430
  _globals['_SCANDATA2205']._serialized_end=1021
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class IOInputValues(_message.Message):
    __slots__ = ["pin_5", "pin_6", "pin_7", "pin_8"]
    PIN_5_FIELD_NUMBER: _ClassVar[int]
    PIN_6_FIELD_NUMBER: _ClassVar[int]
    PIN_7_FIELD_NUMBER: _ClassVar[int]
    PIN_8_FIELD_NUMBER: _ClassVar[int]
    pin_5: int
    pin_6: int
    pin_7: int
    pin_8: int
    def __init__(self, pin_5: _Optional[int] = ..., pin_6: _Optional[int] = ..., pin_7: _Optional[int] = ..., pin_8: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_scheduler_msgs/srv/create_schedule.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_scheduler_msgs.msg import schedule_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__scheduler__msgs_dot_msg_dot_schedule__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/rmf_scheduler_msgs/srv/create_schedule.proto\x12\x33make87_messages_ros2.rolling.rmf_scheduler_msgs.srv\x1a\x42make87_messages_ros2/rolling/rmf_scheduler_msgs/msg/schedule.proto\"h\n\x15\x43reateScheduleRequest\x12O\n\x08schedule\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.rolling.rmf_scheduler_msgs.msg.Schedule\":\n\x16\x43reateScheduleResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_scheduler_msgs.srv.create_schedule_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CREATESCHEDULEREQUEST']._serialized_start=198
  _globals['_CREATESCHEDULEREQUEST']._serialized_end=302
  _globals['_CREATESCHEDULERESPONSE']._serialized_start=304
  _globals['_CREATESCHEDULERESPONSE']._serialized_end=362
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Path(_message.Message):
    __slots__ = ["header", "node_ids", "poses"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NODE_IDS_FIELD_NUMBER: _ClassVar[int]
    POSES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    node_ids: _containers.RepeatedScalarFieldContainer[int]
    poses: _containers.RepeatedCompositeFieldContainer[_pose_pb2.Pose]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., node_ids: _Optional[_Iterable[int]] = ..., poses: _Optional[_Iterable[_Union[_pose_pb2.Pose, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/nicla_vision_ros2/msg/audio_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/nicla_vision_ros2/msg/audio_info.proto\x12\x30make87_messages_ros2.jazzy.nicla_vision_ros2.msg\"q\n\tAudioInfo\x12\x10\n\x08\x63hannels\x18\x01 \x01(\r\x12\x13\n\x0bsample_rate\x18\x02 \x01(\r\x12\x15\n\rsample_format\x18\x03 \x01(\t\x12\x0f\n\x07\x62itrate\x18\x04 \x01(\r\x12\x15\n\rcoding_format\x18\x05 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.nicla_vision_ros2.msg.audio_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_AUDIOINFO']._serialized_start=119
  _globals['_AUDIOINFO']._serialized_end=232
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/plansys2_msgs/msg/durative_action.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.plansys2_msgs.msg import param_pb2 as make87__messages__ros2_dot_humble_dot_plansys2__msgs_dot_msg_dot_param__pb2
from make87_messages_ros2.humble.plansys2_msgs.msg import tree_pb2 as make87__messages__ros2_dot_humble_dot_plansys2__msgs_dot_msg_dot_tree__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/humble/plansys2_msgs/msg/durative_action.proto\x12-make87_messages_ros2.humble.plansys2_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x39make87_messages_ros2/humble/plansys2_msgs/msg/param.proto\x1a\x38make87_messages_ros2/humble/plansys2_msgs/msg/tree.proto\"\xac\x04\n\x0e\x44urativeAction\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04name\x18\x02 \x01(\t\x12H\n\nparameters\x18\x03 \x03(\x0b\x32\x34.make87_messages_ros2.humble.plansys2_msgs.msg.Param\x12R\n\x15\x61t_start_requirements\x18\x04 \x01(\x0b\x32\x33.make87_messages_ros2.humble.plansys2_msgs.msg.Tree\x12R\n\x15over_all_requirements\x18\x05 \x01(\x0b\x32\x33.make87_messages_ros2.humble.plansys2_msgs.msg.Tree\x12P\n\x13\x61t_end_requirements\x18\x06 \x01(\x0b\x32\x33.make87_messages_ros2.humble.plansys2_msgs.msg.Tree\x12M\n\x10\x61t_start_effects\x18\x07 \x01(\x0b\x32\x33.make87_messages_ros2.humble.plansys2_msgs.msg.Tree\x12K\n\x0e\x61t_end_effects\x18\x08 \x01(\x0b\x32\x33.make87_messages_ros2.humble.plansys2_msgs.msg.Treeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.plansys2_msgs.msg.durative_action_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DURATIVEACTION']._serialized_start=271
  _globals['_DURATIVEACTION']._serialized_end=827
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import attached_collision_object_pb2 as _attached_collision_object_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import joint_state_pb2 as _joint_state_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import multi_dof_joint_state_pb2 as _multi_dof_joint_state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RobotState(_message.Message):
    __slots__ = ["header", "joint_state", "multi_dof_joint_state", "attached_collision_objects", "is_diff"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    JOINT_STATE_FIELD_NUMBER: _ClassVar[int]
    MULTI_DOF_JOINT_STATE_FIELD_NUMBER: _ClassVar[int]
    ATTACHED_COLLISION_OBJECTS_FIELD_NUMBER: _ClassVar[int]
    IS_DIFF_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    joint_state: _joint_state_pb2.JointState
    multi_dof_joint_state: _multi_dof_joint_state_pb2.MultiDOFJointState
    attached_collision_objects: _containers.RepeatedCompositeFieldContainer[_attached_collision_object_pb2.AttachedCollisionObject]
    is_diff: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., joint_state: _Optional[_Union[_joint_state_pb2.JointState, _Mapping]] = ..., multi_dof_joint_state: _Optional[_Union[_multi_dof_joint_state_pb2.MultiDOFJointState, _Mapping]] = ..., attached_collision_objects: _Optional[_Iterable[_Union[_attached_collision_object_pb2.AttachedCollisionObject, _Mapping]]] = ..., is_diff: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.ublox_msgs.msg import esf_raw_block_pb2 as _esf_raw_block_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsfRAW(_message.Message):
    __slots__ = ["header", "reserved0", "blocks"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RESERVED0_FIELD_NUMBER: _ClassVar[int]
    BLOCKS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    reserved0: _containers.RepeatedScalarFieldContainer[int]
    blocks: _containers.RepeatedCompositeFieldContainer[_esf_raw_block_pb2.EsfRAWBlock]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., reserved0: _Optional[_Iterable[int]] = ..., blocks: _Optional[_Iterable[_Union[_esf_raw_block_pb2.EsfRAWBlock, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXNavPosECEF(_message.Message):
    __slots__ = ["header", "itow", "ecef_x", "ecef_y", "ecef_z", "p_acc"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ITOW_FIELD_NUMBER: _ClassVar[int]
    ECEF_X_FIELD_NUMBER: _ClassVar[int]
    ECEF_Y_FIELD_NUMBER: _ClassVar[int]
    ECEF_Z_FIELD_NUMBER: _ClassVar[int]
    P_ACC_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    itow: int
    ecef_x: int
    ecef_y: int
    ecef_z: int
    p_acc: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., itow: _Optional[int] = ..., ecef_x: _Optional[int] = ..., ecef_y: _Optional[int] = ..., ecef_z: _Optional[int] = ..., p_acc: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/srv/request_changes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_identity_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_schedule__identity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/rmf_traffic_msgs/srv/request_changes.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.srv\x1aImake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_identity.proto\"O\n\x15RequestChangesRequest\x12\x10\n\x08query_id\x18\x01 \x01(\x04\x12\x0f\n\x07version\x18\x02 \x01(\x04\x12\x13\n\x0b\x66ull_update\x18\x03 \x01(\x08\"\x8d\x01\n\x16RequestChangesResponse\x12T\n\x07node_id\x18\x01 \x01(\x0b\x32\x43.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.ScheduleIdentity\x12\x0e\n\x06result\x18\x02 \x01(\r\x12\r\n\x05\x65rror\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.srv.request_changes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_REQUESTCHANGESREQUEST']._serialized_start=201
  _globals['_REQUESTCHANGESREQUEST']._serialized_end=280
  _globals['_REQUESTCHANGESRESPONSE']._serialized_start=283
  _globals['_REQUESTCHANGESRESPONSE']._serialized_end=424
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class FieldSetReadSrvRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class FieldSetReadSrvResponse(_message.Message):
    __slots__ = ["field_set_selection_method", "active_field_set", "success"]
    FIELD_SET_SELECTION_METHOD_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_SET_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    field_set_selection_method: int
    active_field_set: int
    success: bool
    def __init__(self, field_set_selection_method: _Optional[int] = ..., active_field_set: _Optional[int] = ..., success: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/activity_item.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/activity_item.proto\x12\x36make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg\"v\n\x0c\x41\x63tivityItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x13\n\x0b\x63lient_name\x18\x02 \x01(\t\x12\x15\n\ractivity_type\x18\x03 \x01(\t\x12\x16\n\x0eprevious_value\x18\x04 \x01(\t\x12\x15\n\rcurrent_value\x18\x05 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.activity_item_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ACTIVITYITEM']._serialized_start=134
  _globals['_ACTIVITYITEM']._serialized_end=252
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ros_babel_fish_test_msgs/msg/test_message.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/ros_babel_fish_test_msgs/msg/test_message.proto\x12\x37make87_messages_ros2.jazzy.ros_babel_fish_test_msgs.msg\x1a@make87_messages_ros2/jazzy/builtin_interfaces/msg/duration.proto\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xd3\x03\n\x0bTestMessage\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\t\n\x01\x62\x18\x02 \x01(\x08\x12\x0b\n\x03ui8\x18\x03 \x01(\r\x12\x0c\n\x04ui16\x18\x04 \x01(\r\x12\x0c\n\x04ui32\x18\x05 \x01(\r\x12\x0c\n\x04ui64\x18\x06 \x01(\x04\x12\n\n\x02i8\x18\x07 \x01(\x05\x12\x0b\n\x03i16\x18\x08 \x01(\x05\x12\x0b\n\x03i32\x18\t \x01(\x05\x12\x0b\n\x03i64\x18\n \x01(\x03\x12\x0b\n\x03\x66\x33\x32\x18\x0b \x01(\x02\x12\x0b\n\x03\x66\x36\x34\x18\x0c \x01(\x01\x12\x0b\n\x03str\x18\r \x01(\t\x12\x13\n\x0b\x62ounded_str\x18\x0e \x01(\t\x12\x42\n\x01t\x18\x0f \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12\x46\n\x01\x64\x18\x10 \x01(\x0b\x32;.make87_messages_ros2.jazzy.builtin_interfaces.msg.Duration\x12\x46\n\tpoint_arr\x18\x11 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Pointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ros_babel_fish_test_msgs.msg.test_message_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TESTMESSAGE']._serialized_start=376
  _globals['_TESTMESSAGE']._serialized_end=843
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.jazzy.rc_reason_msgs.msg import range_value_pb2 as _range_value_pb2
from make87_messages_ros2.jazzy.rc_reason_msgs.msg import rectangle_pb2 as _rectangle_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CellFillingLevel(_message.Message):
    __slots__ = ["cell_size", "cell_position", "level_in_percent", "level_free_in_meters", "coverage"]
    CELL_SIZE_FIELD_NUMBER: _ClassVar[int]
    CELL_POSITION_FIELD_NUMBER: _ClassVar[int]
    LEVEL_IN_PERCENT_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FREE_IN_METERS_FIELD_NUMBER: _ClassVar[int]
    COVERAGE_FIELD_NUMBER: _ClassVar[int]
    cell_size: _rectangle_pb2.Rectangle
    cell_position: _point_pb2.Point
    level_in_percent: _range_value_pb2.RangeValue
    level_free_in_meters: _range_value_pb2.RangeValue
    coverage: float
    def __init__(self, cell_size: _Optional[_Union[_rectangle_pb2.Rectangle, _Mapping]] = ..., cell_position: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., level_in_percent: _Optional[_Union[_range_value_pb2.RangeValue, _Mapping]] = ..., level_free_in_meters: _Optional[_Union[_range_value_pb2.RangeValue, _Mapping]] = ..., coverage: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.plansys2_msgs.msg import node_pb2 as _node_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetNodeDetailsRequest(_message.Message):
    __slots__ = ["header", "expression"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    expression: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., expression: _Optional[str] = ...) -> None: ...

class GetNodeDetailsResponse(_message.Message):
    __slots__ = ["header", "success", "node", "error_info"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    NODE_FIELD_NUMBER: _ClassVar[int]
    ERROR_INFO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    node: _node_pb2.Node
    error_info: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., node: _Optional[_Union[_node_pb2.Node, _Mapping]] = ..., error_info: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/gazebo_msgs/srv/get_model_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import twist_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_twist__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/gazebo_msgs/srv/get_model_state.proto\x12+make87_messages_ros2.humble.gazebo_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x38make87_messages_ros2/humble/geometry_msgs/msg/pose.proto\x1a\x39make87_messages_ros2/humble/geometry_msgs/msg/twist.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"v\n\x14GetModelStateRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x1c\n\x14relative_entity_name\x18\x03 \x01(\t\"\xbd\x02\n\x15GetModelStateResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x41\n\x04pose\x18\x03 \x01(\x0b\x32\x33.make87_messages_ros2.humble.geometry_msgs.msg.Pose\x12\x43\n\x05twist\x18\x04 \x01(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Twist\x12\x0f\n\x07success\x18\x05 \x01(\x08\x12\x16\n\x0estatus_message\x18\x06 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.gazebo_msgs.srv.get_model_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETMODELSTATEREQUEST']._serialized_start=321
  _globals['_GETMODELSTATEREQUEST']._serialized_end=439
  _globals['_GETMODELSTATERESPONSE']._serialized_start=442
  _globals['_GETMODELSTATERESPONSE']._serialized_end=759
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.ublox_msgs.msg import esf_status_sens_pb2 as _esf_status_sens_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsfSTATUS(_message.Message):
    __slots__ = ["i_tow", "version", "reserved1", "fusion_mode", "reserved2", "num_sens", "sens"]
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    FUSION_MODE_FIELD_NUMBER: _ClassVar[int]
    RESERVED2_FIELD_NUMBER: _ClassVar[int]
    NUM_SENS_FIELD_NUMBER: _ClassVar[int]
    SENS_FIELD_NUMBER: _ClassVar[int]
    i_tow: int
    version: int
    reserved1: _containers.RepeatedScalarFieldContainer[int]
    fusion_mode: int
    reserved2: _containers.RepeatedScalarFieldContainer[int]
    num_sens: int
    sens: _containers.RepeatedCompositeFieldContainer[_esf_status_sens_pb2.EsfSTATUSSens]
    def __init__(self, i_tow: _Optional[int] = ..., version: _Optional[int] = ..., reserved1: _Optional[_Iterable[int]] = ..., fusion_mode: _Optional[int] = ..., reserved2: _Optional[_Iterable[int]] = ..., num_sens: _Optional[int] = ..., sens: _Optional[_Iterable[_Union[_esf_status_sens_pb2.EsfSTATUSSens, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrajectoryPoint(_message.Message):
    __slots__ = ["header", "time_from_start", "pose", "longitudinal_velocity_mps", "lateral_velocity_mps", "acceleration_mps2", "heading_rate_rps", "front_wheel_angle_rad", "rear_wheel_angle_rad"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIME_FROM_START_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDINAL_VELOCITY_MPS_FIELD_NUMBER: _ClassVar[int]
    LATERAL_VELOCITY_MPS_FIELD_NUMBER: _ClassVar[int]
    ACCELERATION_MPS2_FIELD_NUMBER: _ClassVar[int]
    HEADING_RATE_RPS_FIELD_NUMBER: _ClassVar[int]
    FRONT_WHEEL_ANGLE_RAD_FIELD_NUMBER: _ClassVar[int]
    REAR_WHEEL_ANGLE_RAD_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    time_from_start: _duration_pb2.Duration
    pose: _pose_pb2.Pose
    longitudinal_velocity_mps: float
    lateral_velocity_mps: float
    acceleration_mps2: float
    heading_rate_rps: float
    front_wheel_angle_rad: float
    rear_wheel_angle_rad: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., time_from_start: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., longitudinal_velocity_mps: _Optional[float] = ..., lateral_velocity_mps: _Optional[float] = ..., acceleration_mps2: _Optional[float] = ..., heading_rate_rps: _Optional[float] = ..., front_wheel_angle_rad: _Optional[float] = ..., rear_wheel_angle_rad: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/data_tamer_msgs/msg/snapshot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/data_tamer_msgs/msg/snapshot.proto\x12\x30make87_messages_ros2.rolling.data_tamer_msgs.msg\"]\n\x08Snapshot\x12\x16\n\x0etimestamp_nsec\x18\x01 \x01(\x04\x12\x13\n\x0bschema_hash\x18\x02 \x01(\x04\x12\x13\n\x0b\x61\x63tive_mask\x18\x03 \x03(\r\x12\x0f\n\x07payload\x18\x04 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.data_tamer_msgs.msg.snapshot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SNAPSHOT']._serialized_start=117
  _globals['_SNAPSHOT']._serialized_end=210
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rc_reason_msgs/srv/get_regions_of_interest2_d.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_humble_dot_rc__common__msgs_dot_msg_dot_return__code__pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import region_of_interest2_d_pb2 as make87__messages__ros2_dot_humble_dot_rc__reason__msgs_dot_msg_dot_region__of__interest2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/humble/rc_reason_msgs/srv/get_regions_of_interest2_d.proto\x12.make87_messages_ros2.humble.rc_reason_msgs.srv\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/rc_common_msgs/msg/return_code.proto\x1aJmake87_messages_ros2/humble/rc_reason_msgs/msg/region_of_interest2_d.proto\"p\n\x1dGetRegionsOfInterest2DRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12!\n\x19region_of_interest_2d_ids\x18\x02 \x03(\t\"\x80\x02\n\x1eGetRegionsOfInterest2DResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12_\n\x13regions_of_interest\x18\x02 \x03(\x0b\x32\x42.make87_messages_ros2.humble.rc_reason_msgs.msg.RegionOfInterest2D\x12O\n\x0breturn_code\x18\x03 \x01(\x0b\x32:.make87_messages_ros2.humble.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rc_reason_msgs.srv.get_regions_of_interest2_d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETREGIONSOFINTEREST2DREQUEST']._serialized_start=308
  _globals['_GETREGIONSOFINTEREST2DREQUEST']._serialized_end=420
  _globals['_GETREGIONSOFINTEREST2DRESPONSE']._serialized_start=423
  _globals['_GETREGIONSOFINTEREST2DRESPONSE']._serialized_end=679
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/slam_toolbox/srv/deserialize_pose_graph.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose2_d_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/humble/slam_toolbox/srv/deserialize_pose_graph.proto\x12,make87_messages_ros2.humble.slam_toolbox.srv\x1a!make87_messages/core/header.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/pose2_d.proto\"\xbe\x01\n\x1b\x44\x65serializePoseGraphRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x12\n\nmatch_type\x18\x03 \x01(\x05\x12K\n\x0cinitial_pose\x18\x04 \x01(\x0b\x32\x35.make87_messages_ros2.humble.geometry_msgs.msg.Pose2D\"L\n\x1c\x44\x65serializePoseGraphResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Headerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.slam_toolbox.srv.deserialize_pose_graph_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DESERIALIZEPOSEGRAPHREQUEST']._serialized_start=220
  _globals['_DESERIALIZEPOSEGRAPHREQUEST']._serialized_end=410
  _globals['_DESERIALIZEPOSEGRAPHRESPONSE']._serialized_start=412
  _globals['_DESERIALIZEPOSEGRAPHRESPONSE']._serialized_end=488
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateRigidBodyRequest(_message.Message):
    __slots__ = ["header", "rigid_body_name", "link_parent", "markers"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RIGID_BODY_NAME_FIELD_NUMBER: _ClassVar[int]
    LINK_PARENT_FIELD_NUMBER: _ClassVar[int]
    MARKERS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    rigid_body_name: str
    link_parent: str
    markers: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., rigid_body_name: _Optional[str] = ..., link_parent: _Optional[str] = ..., markers: _Optional[_Iterable[int]] = ...) -> None: ...

class CreateRigidBodyResponse(_message.Message):
    __slots__ = ["header", "success"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/novatel_gps_msgs/msg/time.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/rolling/novatel_gps_msgs/msg/time.proto\x12\x31make87_messages_ros2.rolling.novatel_gps_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xa0\x02\n\x04Time\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x14\n\x0c\x63lock_status\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x01\x12\x12\n\noffset_std\x18\x04 \x01(\x01\x12\x12\n\nutc_offset\x18\x05 \x01(\x01\x12\x10\n\x08utc_year\x18\x06 \x01(\r\x12\x11\n\tutc_month\x18\x07 \x01(\r\x12\x0f\n\x07utc_day\x18\x08 \x01(\r\x12\x10\n\x08utc_hour\x18\t \x01(\r\x12\x12\n\nutc_minute\x18\n \x01(\r\x12\x17\n\x0futc_millisecond\x18\x0b \x01(\r\x12\x12\n\nutc_status\x18\x0c \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.novatel_gps_msgs.msg.time_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TIME']._serialized_start=172
  _globals['_TIME']._serialized_end=460
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_fleet_msgs/msg/robot_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_fleet_msgs.msg import location_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__fleet__msgs_dot_msg_dot_location__pb2
from make87_messages_ros2.rolling.rmf_fleet_msgs.msg import robot_mode_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__fleet__msgs_dot_msg_dot_robot__mode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/rmf_fleet_msgs/msg/robot_state.proto\x12/make87_messages_ros2.rolling.rmf_fleet_msgs.msg\x1a>make87_messages_ros2/rolling/rmf_fleet_msgs/msg/location.proto\x1a@make87_messages_ros2/rolling/rmf_fleet_msgs/msg/robot_mode.proto\"\xc0\x02\n\nRobotState\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05model\x18\x02 \x01(\t\x12\x0f\n\x07task_id\x18\x03 \x01(\t\x12\x0b\n\x03seq\x18\x04 \x01(\x04\x12H\n\x04mode\x18\x05 \x01(\x0b\x32:.make87_messages_ros2.rolling.rmf_fleet_msgs.msg.RobotMode\x12\x17\n\x0f\x62\x61ttery_percent\x18\x06 \x01(\x02\x12K\n\x08location\x18\x07 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.rmf_fleet_msgs.msg.Location\x12G\n\x04path\x18\x08 \x03(\x0b\x32\x39.make87_messages_ros2.rolling.rmf_fleet_msgs.msg.Locationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_fleet_msgs.msg.robot_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROBOTSTATE']._serialized_start=249
  _globals['_ROBOTSTATE']._serialized_end=569
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/gazebo_msgs/srv/delete_entity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/humble/gazebo_msgs/srv/delete_entity.proto\x12+make87_messages_ros2.humble.gazebo_msgs.srv\x1a!make87_messages/core/header.proto\"Q\n\x13\x44\x65leteEntityRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04name\x18\x02 \x01(\t\"m\n\x14\x44\x65leteEntityResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x16\n\x0estatus_message\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.gazebo_msgs.srv.delete_entity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DELETEENTITYREQUEST']._serialized_start=147
  _globals['_DELETEENTITYREQUEST']._serialized_end=228
  _globals['_DELETEENTITYRESPONSE']._serialized_start=230
  _globals['_DELETEENTITYRESPONSE']._serialized_end=339
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from make87_messages_ros2.humble.ublox_ubx_msgs.msg import utc_std_pb2 as _utc_std_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXNavTimeUTC(_message.Message):
    __slots__ = ["header", "ros2_header", "itow", "t_acc", "nano", "year", "month", "day", "hour", "min", "sec", "valid_tow", "valid_wkn", "valid_utc", "utc_std"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    ITOW_FIELD_NUMBER: _ClassVar[int]
    T_ACC_FIELD_NUMBER: _ClassVar[int]
    NANO_FIELD_NUMBER: _ClassVar[int]
    YEAR_FIELD_NUMBER: _ClassVar[int]
    MONTH_FIELD_NUMBER: _ClassVar[int]
    DAY_FIELD_NUMBER: _ClassVar[int]
    HOUR_FIELD_NUMBER: _ClassVar[int]
    MIN_FIELD_NUMBER: _ClassVar[int]
    SEC_FIELD_NUMBER: _ClassVar[int]
    VALID_TOW_FIELD_NUMBER: _ClassVar[int]
    VALID_WKN_FIELD_NUMBER: _ClassVar[int]
    VALID_UTC_FIELD_NUMBER: _ClassVar[int]
    UTC_STD_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    itow: int
    t_acc: int
    nano: int
    year: int
    month: int
    day: int
    hour: int
    min: int
    sec: int
    valid_tow: bool
    valid_wkn: bool
    valid_utc: bool
    utc_std: _utc_std_pb2.UtcStd
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., itow: _Optional[int] = ..., t_acc: _Optional[int] = ..., nano: _Optional[int] = ..., year: _Optional[int] = ..., month: _Optional[int] = ..., day: _Optional[int] = ..., hour: _Optional[int] = ..., min: _Optional[int] = ..., sec: _Optional[int] = ..., valid_tow: bool = ..., valid_wkn: bool = ..., valid_utc: bool = ..., utc_std: _Optional[_Union[_utc_std_pb2.UtcStd, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.kartech_linear_actuator_msgs.msg import report_index_pb2 as _report_index_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScheduledReportRatesReq(_message.Message):
    __slots__ = ["header", "confirm", "index_1", "index_1_report_time", "index_2", "index_2_report_time"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CONFIRM_FIELD_NUMBER: _ClassVar[int]
    INDEX_1_FIELD_NUMBER: _ClassVar[int]
    INDEX_1_REPORT_TIME_FIELD_NUMBER: _ClassVar[int]
    INDEX_2_FIELD_NUMBER: _ClassVar[int]
    INDEX_2_REPORT_TIME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    confirm: bool
    index_1: _report_index_pb2.ReportIndex
    index_1_report_time: int
    index_2: _report_index_pb2.ReportIndex
    index_2_report_time: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., confirm: bool = ..., index_1: _Optional[_Union[_report_index_pb2.ReportIndex, _Mapping]] = ..., index_1_report_time: _Optional[int] = ..., index_2: _Optional[_Union[_report_index_pb2.ReportIndex, _Mapping]] = ..., index_2_report_time: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/test_interface_files/msg/unbounded_sequences.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.test_interface_files.msg import basic_types_pb2 as make87__messages__ros2_dot_rolling_dot_test__interface__files_dot_msg_dot_basic__types__pb2
from make87_messages_ros2.rolling.test_interface_files.msg import constants_pb2 as make87__messages__ros2_dot_rolling_dot_test__interface__files_dot_msg_dot_constants__pb2
from make87_messages_ros2.rolling.test_interface_files.msg import defaults_pb2 as make87__messages__ros2_dot_rolling_dot_test__interface__files_dot_msg_dot_defaults__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/rolling/test_interface_files/msg/unbounded_sequences.proto\x12\x35make87_messages_ros2.rolling.test_interface_files.msg\x1aGmake87_messages_ros2/rolling/test_interface_files/msg/basic_types.proto\x1a\x45make87_messages_ros2/rolling/test_interface_files/msg/constants.proto\x1a\x44make87_messages_ros2/rolling/test_interface_files/msg/defaults.proto\"\xa2\x08\n\x12UnboundedSequences\x12\x13\n\x0b\x62ool_values\x18\x01 \x03(\x08\x12\x13\n\x0b\x62yte_values\x18\x02 \x03(\r\x12\x13\n\x0b\x63har_values\x18\x03 \x03(\x05\x12\x16\n\x0e\x66loat32_values\x18\x04 \x03(\x02\x12\x16\n\x0e\x66loat64_values\x18\x05 \x03(\x01\x12\x13\n\x0bint8_values\x18\x06 \x03(\x05\x12\x14\n\x0cuint8_values\x18\x07 \x03(\r\x12\x14\n\x0cint16_values\x18\x08 \x03(\x05\x12\x15\n\ruint16_values\x18\t \x03(\r\x12\x14\n\x0cint32_values\x18\n \x03(\x05\x12\x15\n\ruint32_values\x18\x0b \x03(\r\x12\x14\n\x0cint64_values\x18\x0c \x03(\x03\x12\x15\n\ruint64_values\x18\r \x03(\x04\x12\x15\n\rstring_values\x18\x0e \x03(\t\x12]\n\x12\x62\x61sic_types_values\x18\x0f \x03(\x0b\x32\x41.make87_messages_ros2.rolling.test_interface_files.msg.BasicTypes\x12Z\n\x10\x63onstants_values\x18\x10 \x03(\x0b\x32@.make87_messages_ros2.rolling.test_interface_files.msg.Constants\x12X\n\x0f\x64\x65\x66\x61ults_values\x18\x11 \x03(\x0b\x32?.make87_messages_ros2.rolling.test_interface_files.msg.Defaults\x12\x1b\n\x13\x62ool_values_default\x18\x12 \x03(\x08\x12\x1b\n\x13\x62yte_values_default\x18\x13 \x03(\r\x12\x1b\n\x13\x63har_values_default\x18\x14 \x03(\x05\x12\x1e\n\x16\x66loat32_values_default\x18\x15 \x03(\x02\x12\x1e\n\x16\x66loat64_values_default\x18\x16 \x03(\x01\x12\x1b\n\x13int8_values_default\x18\x17 \x03(\x05\x12\x1c\n\x14uint8_values_default\x18\x18 \x03(\r\x12\x1c\n\x14int16_values_default\x18\x19 \x03(\x05\x12\x1d\n\x15uint16_values_default\x18\x1a \x03(\r\x12\x1c\n\x14int32_values_default\x18\x1b \x03(\x05\x12\x1d\n\x15uint32_values_default\x18\x1c \x03(\r\x12\x1c\n\x14int64_values_default\x18\x1d \x03(\x03\x12\x1d\n\x15uint64_values_default\x18\x1e \x03(\x04\x12\x1d\n\x15string_values_default\x18\x1f \x03(\t\x12\x17\n\x0f\x61lignment_check\x18  \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.test_interface_files.msg.unbounded_sequences_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UNBOUNDEDSEQUENCES']._serialized_start=353
  _globals['_UNBOUNDEDSEQUENCES']._serialized_end=1411
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/delphi_mrr_msgs/msg/vehicle_state_msg1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/delphi_mrr_msgs/msg/vehicle_state_msg1.proto\x12.make87_messages_ros2.jazzy.delphi_mrr_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xa5\x04\n\x10VehicleStateMsg1\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12!\n\x19\x63\x61n_fcw_sensitivity_level\x18\x02 \x01(\r\x12\x1e\n\x16\x63\x61n_vehicle_stationary\x18\x03 \x01(\x08\x12\x1e\n\x16\x63\x61n_intf_minor_version\x18\x04 \x01(\r\x12\x1e\n\x16\x63\x61n_intf_major_version\x18\x05 \x01(\r\x12\x17\n\x0f\x63\x61n_brake_pedal\x18\x06 \x01(\r\x12\x1b\n\x13\x63\x61n_high_wheel_slip\x18\x07 \x01(\x08\x12\x1e\n\x16\x63\x61n_turn_signal_status\x18\x08 \x01(\r\x12\x1c\n\x14\x63\x61n_washer_front_cmd\x18\t \x01(\x08\x12\x1b\n\x13\x63\x61n_wiper_front_cmd\x18\n \x01(\x08\x12\x1c\n\x14\x63\x61n_wiper_speed_info\x18\x0b \x01(\r\x12\x18\n\x10\x63\x61n_reverse_gear\x18\x0c \x01(\x08\x12#\n\x1b\x63\x61n_beam_shape_actual_right\x18\r \x01(\r\x12\"\n\x1a\x63\x61n_beam_shape_actual_left\x18\x0e \x01(\r\x12 \n\x18\x63\x61n_main_beam_indication\x18\x0f \x01(\x08\x12\x19\n\x11\x63\x61n_vehicle_index\x18\x10 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.delphi_mrr_msgs.msg.vehicle_state_msg1_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_VEHICLESTATEMSG1']._serialized_start=178
  _globals['_VEHICLESTATEMSG1']._serialized_end=727
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BEStatus(_message.Message):
    __slots__ = ["stamp", "behavior_id", "code", "args"]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    BEHAVIOR_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    ARGS_FIELD_NUMBER: _ClassVar[int]
    stamp: _time_pb2.Time
    behavior_id: int
    code: int
    args: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., behavior_id: _Optional[int] = ..., code: _Optional[int] = ..., args: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sensor_msgs/msg/multi_dof_joint_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import transform_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_transform__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import twist_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_twist__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import wrench_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_wrench__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/sensor_msgs/msg/multi_dof_joint_state.proto\x12,make87_messages_ros2.rolling.sensor_msgs.msg\x1a>make87_messages_ros2/rolling/geometry_msgs/msg/transform.proto\x1a:make87_messages_ros2/rolling/geometry_msgs/msg/twist.proto\x1a;make87_messages_ros2/rolling/geometry_msgs/msg/wrench.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xc9\x02\n\x12MultiDOFJointState\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x13\n\x0bjoint_names\x18\x02 \x03(\t\x12M\n\ntransforms\x18\x03 \x03(\x0b\x32\x39.make87_messages_ros2.rolling.geometry_msgs.msg.Transform\x12\x44\n\x05twist\x18\x04 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Twist\x12\x46\n\x06wrench\x18\x05 \x03(\x0b\x32\x36.make87_messages_ros2.rolling.geometry_msgs.msg.Wrenchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sensor_msgs.msg.multi_dof_joint_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MULTIDOFJOINTSTATE']._serialized_start=364
  _globals['_MULTIDOFJOINTSTATE']._serialized_end=693
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rcss3d_agent_msgs/msg/percept.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import accelerometer_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_accelerometer__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import agent_state_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_agent__state__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import force_resistance_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_force__resistance__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import game_state_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_game__state__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import gyro_rate_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_gyro__rate__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import hear_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_hear__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import hinge_joint_pos_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_hinge__joint__pos__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import universal_joint_pos_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_universal__joint__pos__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import vision_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_vision__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/humble/rcss3d_agent_msgs/msg/percept.proto\x12\x31make87_messages_ros2.humble.rcss3d_agent_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x45make87_messages_ros2/humble/rcss3d_agent_msgs/msg/accelerometer.proto\x1a\x43make87_messages_ros2/humble/rcss3d_agent_msgs/msg/agent_state.proto\x1aHmake87_messages_ros2/humble/rcss3d_agent_msgs/msg/force_resistance.proto\x1a\x42make87_messages_ros2/humble/rcss3d_agent_msgs/msg/game_state.proto\x1a\x41make87_messages_ros2/humble/rcss3d_agent_msgs/msg/gyro_rate.proto\x1a<make87_messages_ros2/humble/rcss3d_agent_msgs/msg/hear.proto\x1aGmake87_messages_ros2/humble/rcss3d_agent_msgs/msg/hinge_joint_pos.proto\x1aKmake87_messages_ros2/humble/rcss3d_agent_msgs/msg/universal_joint_pos.proto\x1a>make87_messages_ros2/humble/rcss3d_agent_msgs/msg/vision.proto\"\xb2\x06\n\x07Percept\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12O\n\ngyro_rates\x18\x02 \x03(\x0b\x32;.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.GyroRate\x12V\n\x0chinge_joints\x18\x03 \x03(\x0b\x32@.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.HingeJointPos\x12^\n\x10universal_joints\x18\x04 \x03(\x0b\x32\x44.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.UniversalJointPos\x12]\n\x11\x66orce_resistances\x18\x05 \x03(\x0b\x32\x42.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.ForceResistance\x12X\n\x0e\x61\x63\x63\x65lerometers\x18\x06 \x03(\x0b\x32@.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.Accelerometer\x12I\n\x06vision\x18\x07 \x03(\x0b\x32\x39.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.Vision\x12P\n\ngame_state\x18\x08 \x01(\x0b\x32<.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.GameState\x12R\n\x0b\x61gent_state\x18\t \x03(\x0b\x32=.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.AgentState\x12\x46\n\x05hears\x18\n \x03(\x0b\x32\x37.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.Hearb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rcss3d_agent_msgs.msg.percept_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PERCEPT']._serialized_start=779
  _globals['_PERCEPT']._serialized_end=1597
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/automotive_navigation_msgs/msg/point_of_interest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/rolling/automotive_navigation_msgs/msg/point_of_interest.proto\x12;make87_messages_ros2.rolling.automotive_navigation_msgs.msg\"T\n\x0fPointOfInterest\x12\x0c\n\x04guid\x18\x01 \x01(\x04\x12\x10\n\x08latitude\x18\x02 \x01(\x01\x12\x11\n\tlongitude\x18\x03 \x01(\x01\x12\x0e\n\x06params\x18\x04 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.automotive_navigation_msgs.msg.point_of_interest_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_POINTOFINTEREST']._serialized_start=148
  _globals['_POINTOFINTEREST']._serialized_end=232
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PriorityConfigCmd(_message.Message):
    __slots__ = ["header", "confirm", "handshake_priority", "auto_reply_priority", "scheduled_priority", "polled_priority"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CONFIRM_FIELD_NUMBER: _ClassVar[int]
    HANDSHAKE_PRIORITY_FIELD_NUMBER: _ClassVar[int]
    AUTO_REPLY_PRIORITY_FIELD_NUMBER: _ClassVar[int]
    SCHEDULED_PRIORITY_FIELD_NUMBER: _ClassVar[int]
    POLLED_PRIORITY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    confirm: bool
    handshake_priority: int
    auto_reply_priority: int
    scheduled_priority: int
    polled_priority: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., confirm: bool = ..., handshake_priority: _Optional[int] = ..., auto_reply_priority: _Optional[int] = ..., scheduled_priority: _Optional[int] = ..., polled_priority: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.moveit_msgs.msg import constraints_pb2 as _constraints_pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import generic_trajectory_pb2 as _generic_trajectory_pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import robot_state_pb2 as _robot_state_pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import trajectory_constraints_pb2 as _trajectory_constraints_pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import workspace_parameters_pb2 as _workspace_parameters_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MotionPlanRequest(_message.Message):
    __slots__ = ["workspace_parameters", "start_state", "goal_constraints", "path_constraints", "trajectory_constraints", "reference_trajectories", "pipeline_id", "planner_id", "group_name", "num_planning_attempts", "allowed_planning_time", "max_velocity_scaling_factor", "max_acceleration_scaling_factor", "cartesian_speed_limited_link", "max_cartesian_speed"]
    WORKSPACE_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    START_STATE_FIELD_NUMBER: _ClassVar[int]
    GOAL_CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    PATH_CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    TRAJECTORY_CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_TRAJECTORIES_FIELD_NUMBER: _ClassVar[int]
    PIPELINE_ID_FIELD_NUMBER: _ClassVar[int]
    PLANNER_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_NAME_FIELD_NUMBER: _ClassVar[int]
    NUM_PLANNING_ATTEMPTS_FIELD_NUMBER: _ClassVar[int]
    ALLOWED_PLANNING_TIME_FIELD_NUMBER: _ClassVar[int]
    MAX_VELOCITY_SCALING_FACTOR_FIELD_NUMBER: _ClassVar[int]
    MAX_ACCELERATION_SCALING_FACTOR_FIELD_NUMBER: _ClassVar[int]
    CARTESIAN_SPEED_LIMITED_LINK_FIELD_NUMBER: _ClassVar[int]
    MAX_CARTESIAN_SPEED_FIELD_NUMBER: _ClassVar[int]
    workspace_parameters: _workspace_parameters_pb2.WorkspaceParameters
    start_state: _robot_state_pb2.RobotState
    goal_constraints: _containers.RepeatedCompositeFieldContainer[_constraints_pb2.Constraints]
    path_constraints: _constraints_pb2.Constraints
    trajectory_constraints: _trajectory_constraints_pb2.TrajectoryConstraints
    reference_trajectories: _containers.RepeatedCompositeFieldContainer[_generic_trajectory_pb2.GenericTrajectory]
    pipeline_id: str
    planner_id: str
    group_name: str
    num_planning_attempts: int
    allowed_planning_time: float
    max_velocity_scaling_factor: float
    max_acceleration_scaling_factor: float
    cartesian_speed_limited_link: str
    max_cartesian_speed: float
    def __init__(self, workspace_parameters: _Optional[_Union[_workspace_parameters_pb2.WorkspaceParameters, _Mapping]] = ..., start_state: _Optional[_Union[_robot_state_pb2.RobotState, _Mapping]] = ..., goal_constraints: _Optional[_Iterable[_Union[_constraints_pb2.Constraints, _Mapping]]] = ..., path_constraints: _Optional[_Union[_constraints_pb2.Constraints, _Mapping]] = ..., trajectory_constraints: _Optional[_Union[_trajectory_constraints_pb2.TrajectoryConstraints, _Mapping]] = ..., reference_trajectories: _Optional[_Iterable[_Union[_generic_trajectory_pb2.GenericTrajectory, _Mapping]]] = ..., pipeline_id: _Optional[str] = ..., planner_id: _Optional[str] = ..., group_name: _Optional[str] = ..., num_planning_attempts: _Optional[int] = ..., allowed_planning_time: _Optional[float] = ..., max_velocity_scaling_factor: _Optional[float] = ..., max_acceleration_scaling_factor: _Optional[float] = ..., cartesian_speed_limited_link: _Optional[str] = ..., max_cartesian_speed: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/novatel_gps_msgs/msg/inspvax.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.novatel_gps_msgs.msg import novatel_extended_solution_status_pb2 as make87__messages__ros2_dot_rolling_dot_novatel__gps__msgs_dot_msg_dot_novatel__extended__solution__status__pb2
from make87_messages_ros2.rolling.novatel_gps_msgs.msg import novatel_message_header_pb2 as make87__messages__ros2_dot_rolling_dot_novatel__gps__msgs_dot_msg_dot_novatel__message__header__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/novatel_gps_msgs/msg/inspvax.proto\x12\x31make87_messages_ros2.rolling.novatel_gps_msgs.msg\x1aXmake87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_extended_solution_status.proto\x1aNmake87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_message_header.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xef\x05\n\x07Inspvax\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x63\n\x12novatel_msg_header\x18\x02 \x01(\x0b\x32G.make87_messages_ros2.rolling.novatel_gps_msgs.msg.NovatelMessageHeader\x12\x12\n\nins_status\x18\x03 \x01(\t\x12\x15\n\rposition_type\x18\x04 \x01(\t\x12\x10\n\x08latitude\x18\x05 \x01(\x01\x12\x11\n\tlongitude\x18\x06 \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x07 \x01(\x01\x12\x12\n\nundulation\x18\x08 \x01(\x02\x12\x16\n\x0enorth_velocity\x18\t \x01(\x01\x12\x15\n\reast_velocity\x18\n \x01(\x01\x12\x13\n\x0bup_velocity\x18\x0b \x01(\x01\x12\x0c\n\x04roll\x18\x0c \x01(\x01\x12\r\n\x05pitch\x18\r \x01(\x01\x12\x0f\n\x07\x61zimuth\x18\x0e \x01(\x01\x12\x14\n\x0clatitude_std\x18\x0f \x01(\x02\x12\x15\n\rlongitude_std\x18\x10 \x01(\x02\x12\x14\n\x0c\x61ltitude_std\x18\x11 \x01(\x02\x12\x1a\n\x12north_velocity_std\x18\x12 \x01(\x02\x12\x19\n\x11\x65\x61st_velocity_std\x18\x13 \x01(\x02\x12\x17\n\x0fup_velocity_std\x18\x14 \x01(\x02\x12\x10\n\x08roll_std\x18\x15 \x01(\x02\x12\x11\n\tpitch_std\x18\x16 \x01(\x02\x12\x13\n\x0b\x61zimuth_std\x18\x17 \x01(\x02\x12i\n\x0f\x65xtended_status\x18\x18 \x01(\x0b\x32P.make87_messages_ros2.rolling.novatel_gps_msgs.msg.NovatelExtendedSolutionStatus\x12\x1c\n\x14seconds_since_update\x18\x19 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.novatel_gps_msgs.msg.inspvax_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INSPVAX']._serialized_start=345
  _globals['_INSPVAX']._serialized_end=1096
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/irobot_create_msgs/srv/e_stop.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/irobot_create_msgs/srv/e_stop.proto\x12\x31make87_messages_ros2.jazzy.irobot_create_msgs.srv\"!\n\x0c\x45StopRequest\x12\x11\n\te_stop_on\x18\x01 \x01(\x08\"1\n\rEStopResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.irobot_create_msgs.srv.e_stop_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ESTOPREQUEST']._serialized_start=117
  _globals['_ESTOPREQUEST']._serialized_end=150
  _globals['_ESTOPRESPONSE']._serialized_start=152
  _globals['_ESTOPRESPONSE']._serialized_end=201
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class VersionInfo(_message.Message):
    __slots__ = ["hardware", "firmware", "software"]
    HARDWARE_FIELD_NUMBER: _ClassVar[int]
    FIRMWARE_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_FIELD_NUMBER: _ClassVar[int]
    hardware: str
    firmware: str
    software: str
    def __init__(self, hardware: _Optional[str] = ..., firmware: _Optional[str] = ..., software: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CfgCFG(_message.Message):
    __slots__ = ["header", "clear_mask", "save_mask", "load_mask", "device_mask"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CLEAR_MASK_FIELD_NUMBER: _ClassVar[int]
    SAVE_MASK_FIELD_NUMBER: _ClassVar[int]
    LOAD_MASK_FIELD_NUMBER: _ClassVar[int]
    DEVICE_MASK_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    clear_mask: int
    save_mask: int
    load_mask: int
    device_mask: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., clear_mask: _Optional[int] = ..., save_mask: _Optional[int] = ..., load_mask: _Optional[int] = ..., device_mask: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/plansys2_msgs/msg/action.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.plansys2_msgs.msg import param_pb2 as make87__messages__ros2_dot_jazzy_dot_plansys2__msgs_dot_msg_dot_param__pb2
from make87_messages_ros2.jazzy.plansys2_msgs.msg import tree_pb2 as make87__messages__ros2_dot_jazzy_dot_plansys2__msgs_dot_msg_dot_tree__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/jazzy/plansys2_msgs/msg/action.proto\x12,make87_messages_ros2.jazzy.plansys2_msgs.msg\x1a\x38make87_messages_ros2/jazzy/plansys2_msgs/msg/param.proto\x1a\x37make87_messages_ros2/jazzy/plansys2_msgs/msg/tree.proto\"\xef\x01\n\x06\x41\x63tion\x12\x0c\n\x04name\x18\x01 \x01(\t\x12G\n\nparameters\x18\x02 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.plansys2_msgs.msg.Param\x12I\n\rpreconditions\x18\x03 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.plansys2_msgs.msg.Tree\x12\x43\n\x07\x65\x66\x66\x65\x63ts\x18\x04 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.plansys2_msgs.msg.Treeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.plansys2_msgs.msg.action_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ACTION']._serialized_start=223
  _globals['_ACTION']._serialized_end=462
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/srv/get_planning_scene.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import planning_scene_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_planning__scene__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import planning_scene_components_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_planning__scene__components__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/moveit_msgs/srv/get_planning_scene.proto\x12,make87_messages_ros2.rolling.moveit_msgs.srv\x1a\x41make87_messages_ros2/rolling/moveit_msgs/msg/planning_scene.proto\x1aLmake87_messages_ros2/rolling/moveit_msgs/msg/planning_scene_components.proto\"t\n\x17GetPlanningSceneRequest\x12Y\n\ncomponents\x18\x01 \x01(\x0b\x32\x45.make87_messages_ros2.rolling.moveit_msgs.msg.PlanningSceneComponents\"f\n\x18GetPlanningSceneResponse\x12J\n\x05scene\x18\x01 \x01(\x0b\x32;.make87_messages_ros2.rolling.moveit_msgs.msg.PlanningSceneb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.srv.get_planning_scene_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETPLANNINGSCENEREQUEST']._serialized_start=264
  _globals['_GETPLANNINGSCENEREQUEST']._serialized_end=380
  _globals['_GETPLANNINGSCENERESPONSE']._serialized_start=382
  _globals['_GETPLANNINGSCENERESPONSE']._serialized_end=484
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LandingTarget(_message.Message):
    __slots__ = ["header", "target_num", "frame", "angle", "distance", "size", "pose", "type"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TARGET_NUM_FIELD_NUMBER: _ClassVar[int]
    FRAME_FIELD_NUMBER: _ClassVar[int]
    ANGLE_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    target_num: int
    frame: int
    angle: _containers.RepeatedScalarFieldContainer[float]
    distance: float
    size: _containers.RepeatedScalarFieldContainer[float]
    pose: _pose_pb2.Pose
    type: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., target_num: _Optional[int] = ..., frame: _Optional[int] = ..., angle: _Optional[_Iterable[float]] = ..., distance: _Optional[float] = ..., size: _Optional[_Iterable[float]] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., type: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RxmSFRB(_message.Message):
    __slots__ = ["chn", "svid", "dwrd"]
    CHN_FIELD_NUMBER: _ClassVar[int]
    SVID_FIELD_NUMBER: _ClassVar[int]
    DWRD_FIELD_NUMBER: _ClassVar[int]
    chn: int
    svid: int
    dwrd: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, chn: _Optional[int] = ..., svid: _Optional[int] = ..., dwrd: _Optional[_Iterable[int]] = ...) -> None: ...
